import { useEditor } from "@/modules/editor";
import { css } from "@linaria/core";
import { defineComponent, onMounted, reactive, ref } from "vue";

export const View = defineComponent({
  setup(props, { slots }) {
    const { store, actions } = useEditor();
    const viewRef = ref<HTMLElement>();
    const state = reactive({
      compId: "",
    });
    onMounted(() => {
      const compEl = viewRef.value;
      state.compId = compEl?.getAttribute("data-id") || "";
    });
    return () => {
      const isComp = state.compId;
      const isEdit = store.editMode === "edit";
      const isSelected = isEdit && store.currCompId === state.compId;

      return (
        <div
          ref={viewRef}
          class={
            isEdit && [
              isComp ? viewStyle : "view_inside",
              isSelected && "view_selected",
            ]
          }
          onClick={
            state.compId ? () => actions.pickCurrComp(state.compId) : undefined
          }
        >
          {slots.default?.()}
        </div>
      );
    };
  },
});

const viewStyle = css`
  &:hover {
    outline: 1px dashed @inf-primary-color;
  }

  > * {
    pointer-events: none;
  }

  &.view_selected {
    outline: 1px solid @inf-primary-color;

    > * {
      pointer-events: auto;
    }
    &::after {
      display: none;
    }
    .view_inside:hover {
      outline: 1px dashed @inf-primary-color;
      outline-offset: -1px;
    }
  }
`;
