import { css } from "@linaria/core";
import { IconDelete } from "@queenjs/icons";
import { Image, View } from "@queenjs/ui";
import { defineComponent } from "vue";
import { any } from "vue-types";

export default defineComponent({
  props: {
    record: any(),
  },
  emits: ["delete", "select", "download"],
  setup(props, { emit }) {
    return () => {
      const { record } = props;
      // console.log("record: ", record);
      return (
        <div class={itemStyles}>
          <div class="waiting flex items-center justify-center text-white">
            生成中…
          </div>
          <IconDelete class="icon_del" onClick={() => emit("delete")} />
          <div class="item_actions flex">
            <div class="btn_circle" onClick={() => emit("download")}>
              下载
            </div>
            <div class="btn_circle" onClick={() => emit("select")}>
              使用
            </div>
          </div>
          <View ratio={1.4} class="overflow-hidden">
            <Image class="h-1/1 w-1/1" src="" />
          </View>
        </div>
      );
    };
  },
});

const itemStyles = css`
  position: relative;
  z-index: 1;
  &:hover {
    .icon_del,
    .btn_circle {
      opacity: 1;
    }
  }
  .icon_del,
  .btn_circle {
    opacity: 0;
    transition: all 0.2s ease;
  }

  .item_actions,
  .icon_del,
  .waiting {
    position: absolute;
    z-index: 2;
    color: #fff;
  }
  .item_actions {
    left: 50%;
    top: 50%;
    transform: translate(-50%, -50%);
  }
  .btn_circle {
    border-radius: 50%;
    line-height: 56px;
    width: 56px;
    text-align: center;
    cursor: pointer;
    background-color: rgba(0, 0, 0, 0.7);
    &:hover {
      background-color: rgba(0, 0, 0, 0.8);
    }
    &:not(:first-child) {
      margin-left: 10px;
    }
  }
  .icon_del {
    right: 5px;
    top: 5px;
    border-radius: 2px;
    padding: 3px;
    font-size: 14px;
    cursor: pointer;
    background-color: rgba(0, 0, 0, 0.5);
    &:hover {
      background-color: rgba(0, 0, 0, 0.6);
    }
  }
  .waiting {
    display: none;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    background-color: rgba(0, 0, 0, 0.2);
  }
`;
